@@ -258,25 +258,31 @@ def FindDirFiles(directory = os.getcwd(), types = [], searchchars = [], totalmat
     
         
 
-        if "file" in typefilters: checkfiles.append([file for file in listdir(directory) if isfile(os.path.join(directory, file))]) #Adds all files of type 'file' to the dirfiles list
+        if "file" in typefilters: checkfiles = ([file for file in listdir(directory) if isfile(os.path.join(directory, file))]) #Adds all files of type 'file' to the dirfiles list
 
-        if "directory" in typefilters: checkfiles.append([file for file in listdir(directory) if isdir(os.path.join(directory, file))]) #Adds all directories to the dirfiles list
+        if "directory" in typefilters: checkfiles = ([file for file in listdir(directory) if isdir(os.path.join(directory, file))]) #Adds all directories to the dirfiles list
 
         
-
+    
     else: checkfiles = listdir(directory) #Adds all things to dirfiles if no type was selected for filtering
     
     
     if len(searchchars) > 0: #Avoids unnecessary checking of non-existent criteria (slow)
         for file in checkfiles: #Removes files from dirfiles that do not match the 'searchchars' search criteria
 
-           
+            
             if casesensitive == True:
                 #If any character to be searched for is in the file
-                if totalmatch == False and allscentriespresent == False and any(string in file for string in searchchars): dirfiles.append(file)
+                if totalmatch == False and allscentriespresent == False: 
+                    
+                        
+                    if any(string for string in searchchars if string in file): dirfiles.append(file)
 
                 #Checks how many of the search criteria strings are in the file name, if all must be present. Only appends the file to the dirfiles to be returned if all characters are present
-                elif allscentriespresent == True and len([string for string in searchchars if string in file]) == len(searchchars): dirfiles.append(file)
+                elif allscentriespresent == True: 
+
+                    if len([string for string in searchchars if string in file]) == len(searchchars): dirfiles.append(file)
+                    
 
                 #Checks if the entirety of at least 1 entire string in the searchchars string is in the file name
                 elif totalmatch == True and allscentriespresent == False: 
@@ -594,7 +600,7 @@ def FileTransfer(sourcefile, targetfile,
     
     elif numberofchars > 0:
         charcountread = numberofchars
-        print(charcountread)
+        
         if endpoint < 1 and startpoint > -1:
             endpoint = startpoint + numberofchars
         
@@ -696,7 +702,7 @@ def FileTransfer(sourcefile, targetfile,
 
                     
 
-                    print(str(len(FindInFile(endchar, f1contents2, charinstance2))))
+                    
                     for x in range(len(FindInFile(endchar, f1contents2, charinstance2))):
                         swapped = False
                         startchar = startchar
@@ -707,10 +713,9 @@ def FileTransfer(sourcefile, targetfile,
                             startchar = endchar
                             endchar = startchar2
                             swapped = True
-                            print("swap")
                             
-                        print(endchar)
-                        print(startchar)
+                            
+                        
                         if swapped == True: contentsbuffer.append(f1contents[FindInFile(startchar, f1contents2, charinstance2)[x]:FindInFile(endchar, f1contents2, charinstance1)[x]])
                         else: contentsbuffer.append(f1contents[FindInFile(startchar, f1contents2, charinstance1)[x]:FindInFile(endchar, f1contents2, charinstance2)[x]])
                             
@@ -778,17 +783,16 @@ def FileTransfer(sourcefile, targetfile,
                         if len(chunk) < charcountread2:
                             charcountread2 -= len(chunk)
                             selection.append(chunk)
-                            print("appension")
+                            
                             continue
                         else:
-                            print("no")
+                            
                             selection.append(chunk[:charcountread2])
                             charcountread2 -= len(chunk[:charcountread2])
-                            print(charcountread2)
+                            
                             trailing = False
                             
-                            print(len("".join(x for x in selection)))
-                            print(numberofchars)
+                            
                                 
                             f2.write("".join(x for x in selection))
                             return True
@@ -799,10 +803,10 @@ def FileTransfer(sourcefile, targetfile,
                     
                     if startchar != "" and endchar == "" and numberofchars < 1 and startchar in chunk2:
                         f2.write(chunk[FindInFile(startchar, chunk, charinstance1):])
-                        print("hnn")
+                        
                         writerest = True
                     
-                    print(chunk)
+                    
 
                     if pointflag:
 
@@ -831,7 +835,7 @@ def FileTransfer(sourcefile, targetfile,
                     if startpoint == 0 and numberofchars > 0:
                         
                         for x in range(len(chunk)):
-                            if numberofchars > 0: f2.write(chunk[x]); numberofchars -= 1; print(chunk[x])
+                            if numberofchars > 0: f2.write(chunk[x]); numberofchars -= 1; 
                             else: return True
 
                         continue
@@ -872,14 +876,14 @@ def FileTransfer(sourcefile, targetfile,
                     if startchar != "" and charcountread2 > 0 and endchar == "" and not trailing:
                         if FindInFile(startchar, chunk2)[0] != -1:
                             if FindInFile(startchar, chunk2)[0] + charcountread2 <= len(chunk):
-                                print("gog")
+                                
                                 f2.write(chunk[FindInFile(startchar, chunk2)[0]:FindInFile(startchar, chunk2)[0] + numberofchars])
                                 return True
                             elif FindInFile(startchar, chunk2)[0] + charcountread2 > len(chunk):
                                 selection.append((chunk[FindInFile(startchar, chunk2)[0]:]))
                                 charcountread2 -= len(chunk[FindInFile(startchar, chunk2)[0]:])
                                 trailing = True
-                                print("trailing")
+                                
                                 continue
                         else: continue
                     
